==> wirepas_mesh_messaging-0.1b0.tar.gz: wirepas_mesh_messaging-0.1b0/wirepas_mesh_messaging/request.py <==
"""
    Request
    =======

    .. Copyright:
        Copyright 2019 Wirepas Ltd under Apache License, Version 2.0.
        See file LICENSE for full license details.
"""

import random
from .proto import RequestHeader


class Request(object):
    """
    Request

    Attributes:
        sink_id(str): sink identifier
        req_id (int): identifier to help distinguish a response/request pair
    """

    # pylint: disable=unused-argument
    def __init__(self, sink_id=None, req_id=None, **kwargs):
        super(Request, self).__init__()
        self.sink_id = sink_id
        if req_id is None:
            req_id = random.getrandbits(64)
        self.req_id = req_id

    def __str__(self):
        return str(self.__dict__)

    @property
    def payload(self):
        """ Implement how to serialize child Event classes """
        raise NotImplementedError()

    def _load_request_header(self, request):
        header = request.header
        header.req_id = self.req_id

        if self.sink_id is not None:
            header.sink_id = str(self.sink_id)

    @staticmethod
    def _parse_request_header(header):
        """
        Parses the header details from a protobuff message

        Args:
            header (proto): proto buff message

        Returns:
            A dictionary with the header details
        """
        d = dict()
        d["req_id"] = header.req_id
        if header.HasField("sink_id"):
            d["sink_id"] = header.sink_id
        else:
            d["sink_id"] = None

        return d

==> wirepas_mesh_messaging-1.2.6.tar.gz: wirepas_mesh_messaging-1.2.6/wirepas_mesh_messaging/request.py <==
"""
    Request
    =======

    .. Copyright:
        Copyright 2019 Wirepas Ltd under Apache License, Version 2.0.
        See file LICENSE for full license details.
"""

import random
import time

from .wirepas_message import WirepasMessage


class Request(WirepasMessage):
    """
    Request

    Attributes:
        sink_id(str): sink identifier
        req_id (int): identifier to help distinguish a response/request pair
        time_ms_epoch(int): timestamp in ms of request generation (0 to automatically set it, the default)
    """

    # pylint: disable=unused-argument
    def __init__(self, sink_id=None, req_id=None, time_ms_epoch=0, **kwargs):
        super(Request, self).__init__()
        self.sink_id = sink_id
        if req_id is None:
            req_id = random.getrandbits(64)
        self.req_id = req_id
        if time_ms_epoch == 0:
            time_ms_epoch = int(time.time() * 1000)
        self.time_ms_epoch = time_ms_epoch

    def __str__(self):
        return str(self.__dict__)

    def _load_request_header(self, request):
        header = request.header
        header.req_id = self.req_id

        if self.sink_id is not None:
            header.sink_id = str(self.sink_id)

        if self.time_ms_epoch is not None:
            header.time_ms_epoch = self.time_ms_epoch

    @staticmethod
    def _parse_request_header(header):
        """
        Parses the header details from a protobuff message

        Args:
            header (proto): proto buff message

        Returns:
            A dictionary with the header details
        """
        d = dict()
        d["req_id"] = header.req_id
        if header.HasField("sink_id"):
            d["sink_id"] = header.sink_id
        else:
            d["sink_id"] = None

        if header.HasField("time_ms_epoch"):
            d["time_ms_epoch"] = header.time_ms_epoch
        else:
            d["time_ms_epoch"] = None

        return d
